==> apache-arrow-16.1.0_2.arm64_ventura.bottle.tar.gz: apache-arrow/16.1.0_2/lib/cmake/ArrowFlight/ArrowFlightTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ArrowFlight::arrow_flight_shared" for configuration "RELEASE"
set_property(TARGET ArrowFlight::arrow_flight_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowFlight::arrow_flight_shared PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_flight.1601.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/16.1.0_2/lib/libarrow_flight.1601.dylib"
  )

list(APPEND _cmake_import_check_targets ArrowFlight::arrow_flight_shared )
list(APPEND _cmake_import_check_files_for_ArrowFlight::arrow_flight_shared "${_IMPORT_PREFIX}/lib/libarrow_flight.1601.0.0.dylib" )

# Import target "ArrowFlight::arrow_flight_static" for configuration "RELEASE"
set_property(TARGET ArrowFlight::arrow_flight_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowFlight::arrow_flight_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_flight.a"
  )

list(APPEND _cmake_import_check_targets ArrowFlight::arrow_flight_static )
list(APPEND _cmake_import_check_files_for_ArrowFlight::arrow_flight_static "${_IMPORT_PREFIX}/lib/libarrow_flight.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)

==> apache-arrow-18.0.0.arm64_ventura.bottle.tar.gz: apache-arrow/18.0.0/lib/cmake/ArrowFlight/ArrowFlightTargets-release.cmake <==
#----------------------------------------------------------------
# Generated CMake target import file for configuration "RELEASE".
#----------------------------------------------------------------

# Commands may need to know the format version.
set(CMAKE_IMPORT_FILE_VERSION 1)

# Import target "ArrowFlight::arrow_flight_shared" for configuration "RELEASE"
set_property(TARGET ArrowFlight::arrow_flight_shared APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowFlight::arrow_flight_shared PROPERTIES
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_flight.1800.0.0.dylib"
  IMPORTED_SONAME_RELEASE "@@HOMEBREW_CELLAR@@/apache-arrow/18.0.0/lib/libarrow_flight.1800.dylib"
  )

list(APPEND _cmake_import_check_targets ArrowFlight::arrow_flight_shared )
list(APPEND _cmake_import_check_files_for_ArrowFlight::arrow_flight_shared "${_IMPORT_PREFIX}/lib/libarrow_flight.1800.0.0.dylib" )

# Import target "ArrowFlight::arrow_flight_static" for configuration "RELEASE"
set_property(TARGET ArrowFlight::arrow_flight_static APPEND PROPERTY IMPORTED_CONFIGURATIONS RELEASE)
set_target_properties(ArrowFlight::arrow_flight_static PROPERTIES
  IMPORTED_LINK_INTERFACE_LANGUAGES_RELEASE "CXX"
  IMPORTED_LOCATION_RELEASE "${_IMPORT_PREFIX}/lib/libarrow_flight.a"
  )

list(APPEND _cmake_import_check_targets ArrowFlight::arrow_flight_static )
list(APPEND _cmake_import_check_files_for_ArrowFlight::arrow_flight_static "${_IMPORT_PREFIX}/lib/libarrow_flight.a" )

# Commands beyond this point should not need to know the version.
set(CMAKE_IMPORT_FILE_VERSION)
